<?php

namespace Controllers;

use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Teknisa\GER\Utilities\Environment;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\Controller;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DTO\Response\Notification; 
use Teknisa\Libs\Util\NewCode;

class ParametrosIndicadoresController{
    // /** @var \Services\Settings */
    // private $settingService;
    // /** @var \Services\Password $passwordService */
    // protected $passwordService;
    protected $connection;
    protected $newCode;

    public function __construct($connection, $environment, $newCode) {
        $this->connection = $connection;
        $this->environment = $environment;
        $this->newCode = $newCode;
    }
    
    /**
     * Função responsável por setar os indicadores, os mesmos devem ser setados 
     * a mão.
    */
    
     public function getIndicadorTf(Request $request, Response $response) {
        $filters = array(
            "P_NRORG" => $this->environment->getNrorg(),
            "IND" => "_11_23_29_32_" 
        );
        $stmt = $this->connection->prepare(
            "SELECT
                P.NRPAINEL   AS NRPAINEL,
                NULL AS CODIGO,
                P.NMPAINEL   AS NOME,
                NULL AS VRLIMMETA,
                NULL AS VRLIMMINIMO,
                NULL AS PAI,
                PG.*,
                GP.NMGRUPPROD
            FROM
                PAINEL        P
                LEFT join PARAMGESTAO PG on pg.CDPARAMGESTAO = '0001' LEFT JOIN GRUPPROD GP ON PG.CDGRUPPROD = GP.CDGRUPPROD
            WHERE
                EXISTS (
                    SELECT
                        1
                    FROM
                        INDICADORTF I
                    WHERE
                        I.NRPAINEL = P.NRPAINEL
                        AND INSTR(:IND, '_'
                                        || I.NRINDICADORTF
                                        || '_') > 0
                )
            UNION
            SELECT
                NULL AS NRPAINEL,
                I.NRINDICADORTF   AS CODIGO,
                I.DSINDICADOR     AS NOME,
                I.VRLIMMETA AS VRLIMMETA ,
                I.VRLIMMINIMO AS VRLIMMINIMO,
                I.NRPAINEL        AS PAI,
                PG.*,
                GP.NMGRUPPROD
            FROM
                INDICADORTF   I
                INNER JOIN PAINEL        P ON I.NRPAINEL = P.NRPAINEL
                left OUTER join PARAMGESTAO PG on pg.CDPARAMGESTAO = '0001' LEFT JOIN GRUPPROD GP ON PG.CDGRUPPROD = GP.CDGRUPPROD
            WHERE
                I.NRORG = :P_NRORG
                AND INSTR(:IND, '_'
                                || I.NRINDICADORTF
                                || '_') > 0"
		);
		$stmt->execute($filters);
		$result = $stmt->fetchAll();
		$response->addDataSet(new DataSet("getIndicadorTf", $result));
    } 
    
    public function save(Request $request, Response $response){
        $row = $request->getRow();
        
        try{
            if($row['CDPARAMGESTAO'] != null){
            
                $sql = 'UPDATE PARAMGESTAO SET '.$row['COLUMN']['NAME'].' = :VALUE';
                $stmt = $this->connection->prepare($sql);
                $params = array(
                    'VALUE'  => $row['COLUMN']['VALUE']
                );
            }else{
                //insert na tabela paramgestao
                $sql = "INSERT INTO PARAMGESTAO(CDPARAMGESTAO,".$row['COLUMN']['NAME'].")
                            VALUES ('0001', :VALUE)";
                $stmt = $this->connection->prepare($sql);
                $params = array(
                    'VALUE'  => $row['COLUMN']['VALUE']
                );
                
            }
            $stmt->execute($params);
        } catch (\Exeption $e){
            $this->connection->rollback();
        }
    }
    
    public function saveIndicTrackingAf(Request $request, Response $response) {
        $currentRow = $request->getRow();
        try {
            $params = array(
                "P_VRLIMMETA" => $currentRow["VRLIMMETA"],
                "P_VRLIMMINIMO" => $currentRow["VRLIMMINIMO"],
                "P_NRINDICADORTF" => $currentRow["CODIGO"],
                "P_NRORG" => $this->environment->getNrorg()
            );
           $sql = "UPDATE INDICADORTF
                SET
                    VRLIMMETA = :P_VRLIMMETA,
                    VRLIMMINIMO = :P_VRLIMMINIMO
                WHERE
                    NRINDICADORTF = :P_NRINDICADORTF AND
                    NRORG = :P_NRORG";
		
		$std = $this->connection->prepare($sql);
        $std->execute($params);
            
		}catch(CustomException $e) {
            $response->setError(Utilities::getErrorObjectFromException($e));
        }
    }
} 